[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[vidalia-svn] r1381: When I say "Stop," by golly, I mean it. (trunk/src/control)



Author: edmanm
Date: 2006-10-23 03:09:08 -0400 (Mon, 23 Oct 2006)
New Revision: 1381

Modified:
   trunk/src/control/torcontrol.cpp
Log:
When I say "Stop," by golly, I mean it.


Modified: trunk/src/control/torcontrol.cpp
===================================================================
--- trunk/src/control/torcontrol.cpp	2006-10-23 06:30:29 UTC (rev 1380)
+++ trunk/src/control/torcontrol.cpp	2006-10-23 07:09:08 UTC (rev 1381)
@@ -147,9 +147,9 @@
   if (!isRunning()) {
     return true;
   }
   /* If we didn't start our own Tor, send it a shutdown signal */
   if (!_torProcess) {
-    return this->signal(TorSignal::Shutdown);
+    return this->signal(TorSignal::Halt);
   } else {
     /* We started our own Tor, so stop the process */
     return _torProcess->stop(errmsg);
@@ -147,9 +147,9 @@
     return true;
   }
-  /* If we didn't start our own Tor, send it a shutdown signal */
+  /* If we didn't start our own Tor, send it a halt signal */
   if (!_torProcess) {